<?php

namespace Drupal\user_term_node_access\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\taxonomy\VocabularyInterface;
use Drupal\taxonomy\VocabularyStorageInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Settings form for user_term_node_access.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The vocabulary entity storage.
   *
   * @var \Drupal\taxonomy\VocabularyStorageInterface
   */
  protected VocabularyStorageInterface $vocabularyStorage;

  /**
   * Constructs a SettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($config_factory);
    $this->vocabularyStorage = $entity_type_manager->getStorage('taxonomy_vocabulary');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['user_term_node_access.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'user_term_node_access_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('user_term_node_access.settings');
    $vocabularies = array_map(function (VocabularyInterface $vocabulary) {
      return $vocabulary->label();
    }, $this->vocabularyStorage->loadMultiple());

    $form['user_term_vocabulary'] = [
      '#type' => 'select',
      '#title' => $this->t('Vocabulary'),
      '#description' => $this->t('Configure the vocabulary to use for managing user terms that will define node access.'),
      '#default_value' => $config->get('user_term_vocabulary'),
      '#options' => $vocabularies,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('user_term_node_access.settings')
      ->set('user_term_vocabulary', $form_state->getValue('user_term_vocabulary'))
      ->save();
  }

}
